==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { typeCast, markType, markDep } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var FinancialOverlay = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialOverlay, _super);
    function FinancialOverlay() {
        var _this = _super.call(this) || this;
        _this.tu = false;
        _this.tu = false;
        return _this;
    }
    FinancialOverlay.prototype.get_du = function () {
        return true;
    };
    FinancialOverlay.prototype.k5 = function (a, b, c, d) {
        _super.prototype.k5.call(this, a, b, c, d);
        if (this.qk != null && typeCast(ISortingAxis_$type, this.qk) !== null) {
            this.qk.i$i();
        }
        this.q1.bx.e(this.fx);
        this.tv();
        if (this.q6 != null) {
            this.q6.c0();
        }
        this.mn(true);
    };
    FinancialOverlay.prototype.get_fc = function () {
        return true;
    };
    FinancialOverlay.prototype.l9 = function (a, b, c, d) {
        switch (b) {
            case "FastItemsSource":
                this.tu = false;
                break;
            case FinancialOverlay.$$p[0]:
                this.tu = false;
                this.mn(false);
                this.lu();
                break;
            case "XAxis":
                this.tu = false;
                break;
        }
        _super.prototype.l9.call(this, a, b, c, d);
    };
    FinancialOverlay.prototype.bq = function () {
        if (this.br == 0) {
            return 1;
        }
        else {
            return _super.prototype.bq.call(this);
        }
    };
    FinancialOverlay.prototype.ez = function (a, b) {
        if (this.ey(a, b)) {
            return true;
        }
        return false;
    };
    FinancialOverlay.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mn(false);
    };
    FinancialOverlay.prototype.eq = function (a) {
        var b = this.cl != null ? this.cl.indexOf(a) : -1;
        var c = this.b1.bv;
        c = c.copy();
        var d = this.b1.bu;
        var e = new Rect(0, 0, 0, 1, 1);
        var f = this.p1(this.b1);
        var g = new ScalerParams(0, e, e, this.qk.cg, f);
        var h = new ScalerParams(0, e, e, this.q6.cg, f);
        h.b = this.gg();
        if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
            if (this.qk != null) {
                var i = this.qk.ei(b, g);
                if (i < c.left + 0.1 * c.width) {
                    i = i + 0.4 * c.width;
                }
                if (i > c.right - 0.1 * c.width) {
                    i = i - 0.4 * c.width;
                }
                c.x = i - 0.5 * c.width;
            }
            if (this.q6 != null && this.rf != null && this.re != null && b < this.rf.count && b < this.re.count) {
                var j = this.q6.ei(this.rf.item(b), h);
                var k = this.q6.ei(this.re.item(b), h);
                if (!isNaN_(j) && !isNaN_(k)) {
                    var l = Math.abs(j - k);
                    if (c.height < l) {
                        c.height = l;
                        c.y = Math.min(j, k);
                    }
                    else {
                        if (j < c.top + 0.1 * c.height) {
                            j = j + 0.4 * c.height;
                        }
                        if (j > c.bottom - 0.1 * c.height) {
                            j = j - 0.4 * c.height;
                        }
                        c.y = j - 0.5 * c.height;
                    }
                }
            }
            this.b9.au(this.ce, c, true);
        }
        return b >= 0;
    };
    FinancialOverlay.prototype.aq = function (a) {
        if (a != null && a == this.q6 && this.rf != null && this.re != null) {
            return new AxisRange(this.rf.minimum, this.re.maximum);
        }
        return null;
    };
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    FinancialOverlay.$$p = markDep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:tw:ty', [1, 0]]);
    return FinancialOverlay;
}(FinancialSeries));
export { FinancialOverlay };

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm5/lib/FinancialOverlay.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { FinancialSeries } from "./FinancialSeries";
import { DependencyProperty } from "igniteui-angular-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { typeCast, markType, markDep } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { AxisRange } from "./AxisRange";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var FinancialOverlay = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialOverlay, _super);
    function FinancialOverlay() {
        var _this = _super.call(this) || this;
        _this.tu = false;
        _this.tu = false;
        return _this;
    }
    FinancialOverlay.prototype.get_du = function () {
        return true;
    };
    FinancialOverlay.prototype.k5 = function (a, b, c, d) {
        _super.prototype.k5.call(this, a, b, c, d);
        if (this.qk != null && typeCast(ISortingAxis_$type, this.qk) !== null) {
            this.qk.i$i();
        }
        this.q1.bx.e(this.fx);
        this.tv();
        if (this.q6 != null) {
            this.q6.c1();
        }
        this.mn(true);
    };
    FinancialOverlay.prototype.get_fc = function () {
        return true;
    };
    FinancialOverlay.prototype.l9 = function (a, b, c, d) {
        switch (b) {
            case "FastItemsSource":
                this.tu = false;
                break;
            case FinancialOverlay.$$p[0]:
                this.tu = false;
                this.mn(false);
                this.lu();
                break;
            case "XAxis":
                this.tu = false;
                break;
        }
        _super.prototype.l9.call(this, a, b, c, d);
    };
    FinancialOverlay.prototype.bq = function () {
        if (this.br == 0) {
            return 1;
        }
        else {
            return _super.prototype.bq.call(this);
        }
    };
    FinancialOverlay.prototype.ez = function (a, b) {
        if (this.ey(a, b)) {
            return true;
        }
        return false;
    };
    FinancialOverlay.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mn(false);
    };
    FinancialOverlay.prototype.eq = function (a) {
        var b = this.cl != null ? this.cl.indexOf(a) : -1;
        var c = this.b1.bv;
        c = c.copy();
        var d = this.b1.bu;
        var e = new Rect(0, 0, 0, 1, 1);
        var f = this.p1(this.b1);
        var g = new ScalerParams(0, e, e, this.qk.ch, f);
        var h = new ScalerParams(0, e, e, this.q6.ch, f);
        h.b = this.gg();
        if (b >= 0 && Rect.l_op_Inequality(c, null) && Rect.l_op_Inequality(d, null)) {
            if (this.qk != null) {
                var i = this.qk.ej(b, g);
                if (i < c.left + 0.1 * c.width) {
                    i = i + 0.4 * c.width;
                }
                if (i > c.right - 0.1 * c.width) {
                    i = i - 0.4 * c.width;
                }
                c.x = i - 0.5 * c.width;
            }
            if (this.q6 != null && this.rf != null && this.re != null && b < this.rf.count && b < this.re.count) {
                var j = this.q6.ej(this.rf.item(b), h);
                var k = this.q6.ej(this.re.item(b), h);
                if (!isNaN_(j) && !isNaN_(k)) {
                    var l = Math.abs(j - k);
                    if (c.height < l) {
                        c.height = l;
                        c.y = Math.min(j, k);
                    }
                    else {
                        if (j < c.top + 0.1 * c.height) {
                            j = j + 0.4 * c.height;
                        }
                        if (j > c.bottom - 0.1 * c.height) {
                            j = j - 0.4 * c.height;
                        }
                        c.y = j - 0.5 * c.height;
                    }
                }
            }
            this.b9.au(this.ce, c, true);
        }
        return b >= 0;
    };
    FinancialOverlay.prototype.aq = function (a) {
        if (a != null && a == this.q6 && this.rf != null && this.re != null) {
            return new AxisRange(this.rf.minimum, this.re.maximum);
        }
        return null;
    };
    FinancialOverlay.$t = markType(FinancialOverlay, 'FinancialOverlay', FinancialSeries.$);
    FinancialOverlay.$$p = markDep(DependencyProperty, PropertyMetadata, FinancialOverlay, 'raisePropertyChanged', ['IgnoreFirst:tw:ty', [1, 0]]);
    return FinancialOverlay;
}(FinancialSeries));
export { FinancialOverlay };
